package com.ruoyi.project.business.service.quotation.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.business.domain.TqSpecificationNonStandard;
import com.ruoyi.project.business.mapper.quotation.TqSpecificationNonStandardMapper;
import com.ruoyi.project.business.service.quotation.ITqSpecificationNonStandardService;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2024-05-27
 */
@Service
public class TqSpecificationNonStandardServiceImpl extends
    ServiceImpl<TqSpecificationNonStandardMapper, TqSpecificationNonStandard> implements
    ITqSpecificationNonStandardService {

    @Resource
    private TqSpecificationNonStandardMapper tqSpecificationNonStandardMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public TqSpecificationNonStandard selectTqSpecificationNonStandardById(Long id) {
        return tqSpecificationNonStandardMapper.selectTqSpecificationNonStandardById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tqSpecificationNonStandard 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TqSpecificationNonStandard> selectTqSpecificationNonStandardList(
        TqSpecificationNonStandard tqSpecificationNonStandard) {
        return tqSpecificationNonStandardMapper.selectTqSpecificationNonStandardList(tqSpecificationNonStandard);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param tqSpecificationNonStandard 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTqSpecificationNonStandard(TqSpecificationNonStandard tqSpecificationNonStandard) {
        tqSpecificationNonStandard.setCreateTime(DateUtils.getNowDate());
        return tqSpecificationNonStandardMapper.insertTqSpecificationNonStandard(tqSpecificationNonStandard);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param tqSpecificationNonStandard 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTqSpecificationNonStandard(TqSpecificationNonStandard tqSpecificationNonStandard) {
        tqSpecificationNonStandard.setUpdateTime(DateUtils.getNowDate());
        return tqSpecificationNonStandardMapper.updateTqSpecificationNonStandard(tqSpecificationNonStandard);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTqSpecificationNonStandardByIds(Long[] ids) {
        return tqSpecificationNonStandardMapper.deleteTqSpecificationNonStandardByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTqSpecificationNonStandardById(Long id) {
        return tqSpecificationNonStandardMapper.deleteTqSpecificationNonStandardById(id);
    }
}
