package com.ruoyi.project.business.controller.quotation;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.business.domain.TqSpecificationNonStandard;
import com.ruoyi.project.business.service.quotation.ITqSpecificationNonStandardService;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2024-05-27
 */
@RestController
@RequestMapping("/system/standard")
public class TqSpecificationNonStandardController extends BaseController {

    @Resource
    private ITqSpecificationNonStandardService tqSpecificationNonStandardService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:list')")
    @GetMapping("/list")
    public TableDataInfo list(TqSpecificationNonStandard tqSpecificationNonStandard) {
        startPage();
        List<TqSpecificationNonStandard> list = tqSpecificationNonStandardService.selectTqSpecificationNonStandardList(
            tqSpecificationNonStandard);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TqSpecificationNonStandard tqSpecificationNonStandard) {
        List<TqSpecificationNonStandard> list = tqSpecificationNonStandardService.selectTqSpecificationNonStandardList(
            tqSpecificationNonStandard);
        ExcelUtil<TqSpecificationNonStandard> util = new ExcelUtil<TqSpecificationNonStandard>(
            TqSpecificationNonStandard.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tqSpecificationNonStandardService.selectTqSpecificationNonStandardById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TqSpecificationNonStandard tqSpecificationNonStandard) {
        return toAjax(tqSpecificationNonStandardService.insertTqSpecificationNonStandard(tqSpecificationNonStandard));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TqSpecificationNonStandard tqSpecificationNonStandard) {
        return toAjax(tqSpecificationNonStandardService.updateTqSpecificationNonStandard(tqSpecificationNonStandard));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tqSpecificationNonStandardService.deleteTqSpecificationNonStandardByIds(ids));
    }
}
